@@ -1,4 +1,4 @@
-//@line 40 "/usr/obj/ports/mozilla-thunderbird-2.0.0.19p0/mozilla/toolkit/content/contentAreaUtils.js"
+//@line 40 "/usr/obj/ports/mozilla-thunderbird-2.0.0.22/mozilla/toolkit/content/contentAreaUtils.js"
 
 
 /**
@@ -296,7 +296,7 @@ function internalSave(aURL, aDocument, aDefaultFileName, aContentDisposition,
                    saveAsType == kSaveAsType_Text) ?
                    "text/plain" : aContentType,
     target      : fileURL,
-    postData    : isDocument ? getPostData() : null,
+    postData    : isDocument ? getPostData(aDocument) : null,
     bypassCache : aShouldBypassCache
   };
 
@@ -462,9 +462,9 @@ function getTargetFile(aFpP, aSkipPrompt)
     if (aFolderType != "Downloads")
       throw "ASSERTION FAILED: folder type should be 'Desktop' or 'Downloads'";
     
-//@line 509 "/usr/obj/ports/mozilla-thunderbird-2.0.0.19p0/mozilla/toolkit/content/contentAreaUtils.js"
+//@line 509 "/usr/obj/ports/mozilla-thunderbird-2.0.0.22/mozilla/toolkit/content/contentAreaUtils.js"
     return "Home";
-//@line 512 "/usr/obj/ports/mozilla-thunderbird-2.0.0.19p0/mozilla/toolkit/content/contentAreaUtils.js"
+//@line 512 "/usr/obj/ports/mozilla-thunderbird-2.0.0.22/mozilla/toolkit/content/contentAreaUtils.js"
   }
   
   function getDownloadsFolder(aFolder)
@@ -663,14 +663,16 @@ function appendFiltersForContentType(aFilePicker, aContentType, aFileExtension,
   aFilePicker.appendFilters(Components.interfaces.nsIFilePicker.filterAll);
 }
 
-
-function getPostData()
+function getPostData(aDocument)
 {
   try {
-    var sessionHistory = getWebNavigation().sessionHistory;
-    var entry = sessionHistory.getEntryAtIndex(sessionHistory.index, false);
-    entry = entry.QueryInterface(Components.interfaces.nsISHEntry);
-    return entry.postData;
+    var sessionHistory = aDocument.defaultView
+                                  .QueryInterface(Components.interfaces.nsIInterfaceRequestor)
+                                  .getInterface(Components.interfaces.nsIWebNavigation)
+                                  .sessionHistory;
+    return sessionHistory.getEntryAtIndex(sessionHistory.index, false)
+                         .QueryInterface(Components.interfaces.nsISHEntry)
+                         .postData;
   }
   catch (e) {
   }
@@ -852,7 +854,7 @@ function getNormalizedLeafName(aFile, aDefaultExtension)
   if (!aDefaultExtension)
     return aFile;
 
-//@line 903 "/usr/obj/ports/mozilla-thunderbird-2.0.0.19p0/mozilla/toolkit/content/contentAreaUtils.js"
+//@line 905 "/usr/obj/ports/mozilla-thunderbird-2.0.0.22/mozilla/toolkit/content/contentAreaUtils.js"
 
   // Remove leading dots
   aFile = aFile.replace(/^\.+/, "");
