@@ -1,4 +1,4 @@
-//@line 40 "/usr/obj/ports/mozilla-thunderbird-2.0.0.19p0/mozilla/mail/base/content/mail3PaneWindowCommands.js"
+//@line 40 "/usr/obj/ports/mozilla-thunderbird-2.0.0.22/mozilla/mail/base/content/mail3PaneWindowCommands.js"
 
 var promptService = Components.classes["@mozilla.org/embedcomp/prompt-service;1"].getService(Components.interfaces.nsIPromptService);
 var gMessengerBundle = document.getElementById("bundle_messenger");
@@ -1041,8 +1041,11 @@ function SetFocusThreadPane()
 
 function SetFocusMessagePane()
 {
-  // messagePaneFrame.focus() fails to blur the currently focused element
-  document.commandDispatcher.advanceFocusIntoSubtree(GetMessagePane());
+  // Calling .focus() on content doesn't blur the previously focused chrome
+  // element, so we shift focus to the XUL pane first, to not leave another
+  // pane looking like it has focus.
+  GetMessagePane().focus();
+  GetMessagePaneFrame().focus();
 }
 
 function is_collapsed(element)
